==> knative-model-6.2.0-sources.jar: io/fabric8/knative/eventing/contrib/couchdb/v1alpha1/CouchDbSourceSpecFluentImpl.java <==
package io.fabric8.knative.eventing.contrib.couchdb.v1alpha1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.Destination;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluentImpl;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CouchDbSourceSpecFluentImpl<A extends CouchDbSourceSpecFluent<A>> extends BaseFluent<A> implements CouchDbSourceSpecFluent<A>{
  public CouchDbSourceSpecFluentImpl() {
  }
  public CouchDbSourceSpecFluentImpl(CouchDbSourceSpec instance) {
    this.withCredentials(instance.getCredentials()); 
    this.withDatabase(instance.getDatabase()); 
    this.withFeed(instance.getFeed()); 
    this.withServiceAccountName(instance.getServiceAccountName()); 
    this.withSink(instance.getSink()); 
  }
  private ObjectReferenceBuilder credentials;
  private String database;
  private String feed;
  private String serviceAccountName;
  private DestinationBuilder sink;
  
  /**
   * This method has been deprecated, please use method buildCredentials instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectReference getCredentials() {
    return this.credentials!=null ?this.credentials.build():null;
  }
  public ObjectReference buildCredentials() {
    return this.credentials!=null ?this.credentials.build():null;
  }
  public A withCredentials(ObjectReference credentials) {
    _visitables.get("credentials").remove(this.credentials);
    if (credentials!=null){ this.credentials= new ObjectReferenceBuilder(credentials); _visitables.get("credentials").add(this.credentials);} else { this.credentials = null; _visitables.get("credentials").remove(this.credentials); } return (A) this;
  }
  public Boolean hasCredentials() {
    return this.credentials != null;
  }
  public CouchDbSourceSpecFluent.CredentialsNested<A> withNewCredentials() {
    return new CouchDbSourceSpecFluentImpl.CredentialsNestedImpl();
  }
  public CouchDbSourceSpecFluent.CredentialsNested<A> withNewCredentialsLike(ObjectReference item) {
    return new CouchDbSourceSpecFluentImpl.CredentialsNestedImpl(item);
  }
  public CouchDbSourceSpecFluent.CredentialsNested<A> editCredentials() {
    return withNewCredentialsLike(getCredentials());
  }
  public CouchDbSourceSpecFluent.CredentialsNested<A> editOrNewCredentials() {
    return withNewCredentialsLike(getCredentials() != null ? getCredentials(): new ObjectReferenceBuilder().build());
  }
  public CouchDbSourceSpecFluent.CredentialsNested<A> editOrNewCredentialsLike(ObjectReference item) {
    return withNewCredentialsLike(getCredentials() != null ? getCredentials(): item);
  }
  public String getDatabase() {
    return this.database;
  }
  public A withDatabase(String database) {
    this.database=database; return (A) this;
  }
  public Boolean hasDatabase() {
    return this.database != null;
  }
  public String getFeed() {
    return this.feed;
  }
  public A withFeed(String feed) {
    this.feed=feed; return (A) this;
  }
  public Boolean hasFeed() {
    return this.feed != null;
  }
  public String getServiceAccountName() {
    return this.serviceAccountName;
  }
  public A withServiceAccountName(String serviceAccountName) {
    this.serviceAccountName=serviceAccountName; return (A) this;
  }
  public Boolean hasServiceAccountName() {
    return this.serviceAccountName != null;
  }
  
  /**
   * This method has been deprecated, please use method buildSink instead.
   * @return The buildable object.
   */
  @Deprecated
  public Destination getSink() {
    return this.sink!=null ?this.sink.build():null;
  }
  public Destination buildSink() {
    return this.sink!=null ?this.sink.build():null;
  }
  public A withSink(Destination sink) {
    _visitables.get("sink").remove(this.sink);
    if (sink!=null){ this.sink= new DestinationBuilder(sink); _visitables.get("sink").add(this.sink);} else { this.sink = null; _visitables.get("sink").remove(this.sink); } return (A) this;
  }
  public Boolean hasSink() {
    return this.sink != null;
  }
  public CouchDbSourceSpecFluent.SinkNested<A> withNewSink() {
    return new CouchDbSourceSpecFluentImpl.SinkNestedImpl();
  }
  public CouchDbSourceSpecFluent.SinkNested<A> withNewSinkLike(Destination item) {
    return new CouchDbSourceSpecFluentImpl.SinkNestedImpl(item);
  }
  public CouchDbSourceSpecFluent.SinkNested<A> editSink() {
    return withNewSinkLike(getSink());
  }
  public CouchDbSourceSpecFluent.SinkNested<A> editOrNewSink() {
    return withNewSinkLike(getSink() != null ? getSink(): new DestinationBuilder().build());
  }
  public CouchDbSourceSpecFluent.SinkNested<A> editOrNewSinkLike(Destination item) {
    return withNewSinkLike(getSink() != null ? getSink(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CouchDbSourceSpecFluentImpl that = (CouchDbSourceSpecFluentImpl) o;
    if (credentials != null ? !credentials.equals(that.credentials) :that.credentials != null) return false;
    if (database != null ? !database.equals(that.database) :that.database != null) return false;
    if (feed != null ? !feed.equals(that.feed) :that.feed != null) return false;
    if (serviceAccountName != null ? !serviceAccountName.equals(that.serviceAccountName) :that.serviceAccountName != null) return false;
    if (sink != null ? !sink.equals(that.sink) :that.sink != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(credentials,  database,  feed,  serviceAccountName,  sink,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (credentials != null) { sb.append("credentials:"); sb.append(credentials + ","); }
    if (database != null) { sb.append("database:"); sb.append(database + ","); }
    if (feed != null) { sb.append("feed:"); sb.append(feed + ","); }
    if (serviceAccountName != null) { sb.append("serviceAccountName:"); sb.append(serviceAccountName + ","); }
    if (sink != null) { sb.append("sink:"); sb.append(sink); }
    sb.append("}");
    return sb.toString();
  }
  class CredentialsNestedImpl<N> extends ObjectReferenceFluentImpl<CouchDbSourceSpecFluent.CredentialsNested<N>> implements CouchDbSourceSpecFluent.CredentialsNested<N>,Nested<N>{
    CredentialsNestedImpl(ObjectReference item) {
      this.builder = new ObjectReferenceBuilder(this, item);
    }
    CredentialsNestedImpl() {
      this.builder = new ObjectReferenceBuilder(this);
    }
    ObjectReferenceBuilder builder;
    public N and() {
      return (N) CouchDbSourceSpecFluentImpl.this.withCredentials(builder.build());
    }
    public N endCredentials() {
      return and();
    }
    
  }
  class SinkNestedImpl<N> extends DestinationFluentImpl<CouchDbSourceSpecFluent.SinkNested<N>> implements CouchDbSourceSpecFluent.SinkNested<N>,Nested<N>{
    SinkNestedImpl(Destination item) {
      this.builder = new DestinationBuilder(this, item);
    }
    SinkNestedImpl() {
      this.builder = new DestinationBuilder(this);
    }
    DestinationBuilder builder;
    public N and() {
      return (N) CouchDbSourceSpecFluentImpl.this.withSink(builder.build());
    }
    public N endSink() {
      return and();
    }
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/eventing/contrib/couchdb/v1alpha1/CouchDbSourceSpecFluentImpl.java <==
package io.fabric8.knative.eventing.contrib.couchdb.v1alpha1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.Destination;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluentImpl;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CouchDbSourceSpecFluentImpl<A extends CouchDbSourceSpecFluent<A>> extends BaseFluent<A> implements CouchDbSourceSpecFluent<A>{
  public CouchDbSourceSpecFluentImpl() {
  }
  public CouchDbSourceSpecFluentImpl(CouchDbSourceSpec instance) {
    if (instance != null) {
      this.withCredentials(instance.getCredentials());
      this.withDatabase(instance.getDatabase());
      this.withFeed(instance.getFeed());
      this.withServiceAccountName(instance.getServiceAccountName());
      this.withSink(instance.getSink());
    }
  }
  private ObjectReferenceBuilder credentials;
  private String database;
  private String feed;
  private String serviceAccountName;
  private DestinationBuilder sink;
  
  /**
   * This method has been deprecated, please use method buildCredentials instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectReference getCredentials() {
    return this.credentials!=null ?this.credentials.build():null;
  }
  public ObjectReference buildCredentials() {
    return this.credentials!=null ?this.credentials.build():null;
  }
  public A withCredentials(ObjectReference credentials) {
    _visitables.get("credentials").remove(this.credentials);
    if (credentials!=null){ this.credentials= new ObjectReferenceBuilder(credentials); _visitables.get("credentials").add(this.credentials);} else { this.credentials = null; _visitables.get("credentials").remove(this.credentials); } return (A) this;
  }
  public Boolean hasCredentials() {
    return this.credentials != null;
  }
  public CouchDbSourceSpecFluentImpl.CredentialsNested<A> withNewCredentials() {
    return new CouchDbSourceSpecFluentImpl.CredentialsNestedImpl();
  }
  public CouchDbSourceSpecFluentImpl.CredentialsNested<A> withNewCredentialsLike(ObjectReference item) {
    return new CouchDbSourceSpecFluentImpl.CredentialsNestedImpl(item);
  }
  public CouchDbSourceSpecFluentImpl.CredentialsNested<A> editCredentials() {
    return withNewCredentialsLike(getCredentials());
  }
  public CouchDbSourceSpecFluentImpl.CredentialsNested<A> editOrNewCredentials() {
    return withNewCredentialsLike(getCredentials() != null ? getCredentials(): new ObjectReferenceBuilder().build());
  }
  public CouchDbSourceSpecFluentImpl.CredentialsNested<A> editOrNewCredentialsLike(ObjectReference item) {
    return withNewCredentialsLike(getCredentials() != null ? getCredentials(): item);
  }
  public String getDatabase() {
    return this.database;
  }
  public A withDatabase(String database) {
    this.database=database; return (A) this;
  }
  public Boolean hasDatabase() {
    return this.database != null;
  }
  public String getFeed() {
    return this.feed;
  }
  public A withFeed(String feed) {
    this.feed=feed; return (A) this;
  }
  public Boolean hasFeed() {
    return this.feed != null;
  }
  public String getServiceAccountName() {
    return this.serviceAccountName;
  }
  public A withServiceAccountName(String serviceAccountName) {
    this.serviceAccountName=serviceAccountName; return (A) this;
  }
  public Boolean hasServiceAccountName() {
    return this.serviceAccountName != null;
  }
  
  /**
   * This method has been deprecated, please use method buildSink instead.
   * @return The buildable object.
   */
  @Deprecated
  public Destination getSink() {
    return this.sink!=null ?this.sink.build():null;
  }
  public Destination buildSink() {
    return this.sink!=null ?this.sink.build():null;
  }
  public A withSink(Destination sink) {
    _visitables.get("sink").remove(this.sink);
    if (sink!=null){ this.sink= new DestinationBuilder(sink); _visitables.get("sink").add(this.sink);} else { this.sink = null; _visitables.get("sink").remove(this.sink); } return (A) this;
  }
  public Boolean hasSink() {
    return this.sink != null;
  }
  public CouchDbSourceSpecFluentImpl.SinkNested<A> withNewSink() {
    return new CouchDbSourceSpecFluentImpl.SinkNestedImpl();
  }
  public CouchDbSourceSpecFluentImpl.SinkNested<A> withNewSinkLike(Destination item) {
    return new CouchDbSourceSpecFluentImpl.SinkNestedImpl(item);
  }
  public CouchDbSourceSpecFluentImpl.SinkNested<A> editSink() {
    return withNewSinkLike(getSink());
  }
  public CouchDbSourceSpecFluentImpl.SinkNested<A> editOrNewSink() {
    return withNewSinkLike(getSink() != null ? getSink(): new DestinationBuilder().build());
  }
  public CouchDbSourceSpecFluentImpl.SinkNested<A> editOrNewSinkLike(Destination item) {
    return withNewSinkLike(getSink() != null ? getSink(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CouchDbSourceSpecFluentImpl that = (CouchDbSourceSpecFluentImpl) o;
    if (!java.util.Objects.equals(credentials, that.credentials)) return false;

    if (!java.util.Objects.equals(database, that.database)) return false;

    if (!java.util.Objects.equals(feed, that.feed)) return false;

    if (!java.util.Objects.equals(serviceAccountName, that.serviceAccountName)) return false;

    if (!java.util.Objects.equals(sink, that.sink)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(credentials,  database,  feed,  serviceAccountName,  sink,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (credentials != null) { sb.append("credentials:"); sb.append(credentials + ","); }
    if (database != null) { sb.append("database:"); sb.append(database + ","); }
    if (feed != null) { sb.append("feed:"); sb.append(feed + ","); }
    if (serviceAccountName != null) { sb.append("serviceAccountName:"); sb.append(serviceAccountName + ","); }
    if (sink != null) { sb.append("sink:"); sb.append(sink); }
    sb.append("}");
    return sb.toString();
  }
  class CredentialsNestedImpl<N> extends ObjectReferenceFluentImpl<CouchDbSourceSpecFluentImpl.CredentialsNested<N>> implements CouchDbSourceSpecFluentImpl.CredentialsNested<N>,Nested<N>{
    CredentialsNestedImpl(ObjectReference item) {
      this.builder = new ObjectReferenceBuilder(this, item);
    }
    CredentialsNestedImpl() {
      this.builder = new ObjectReferenceBuilder(this);
    }
    ObjectReferenceBuilder builder;
    public N and() {
      return (N) CouchDbSourceSpecFluentImpl.this.withCredentials(builder.build());
    }
    public N endCredentials() {
      return and();
    }
    
  }
  class SinkNestedImpl<N> extends DestinationFluentImpl<CouchDbSourceSpecFluentImpl.SinkNested<N>> implements CouchDbSourceSpecFluentImpl.SinkNested<N>,Nested<N>{
    SinkNestedImpl(Destination item) {
      this.builder = new DestinationBuilder(this, item);
    }
    SinkNestedImpl() {
      this.builder = new DestinationBuilder(this);
    }
    DestinationBuilder builder;
    public N and() {
      return (N) CouchDbSourceSpecFluentImpl.this.withSink(builder.build());
    }
    public N endSink() {
      return and();
    }
    
  }
  
}
